@@ -1,7 +1,10 @@
+#define _GNU_SOURCE
+
 #include<errno.h>
 #include<string.h>
 #include<stdio.h>
 #include<stdlib.h>
+#include<time.h>
 #include<unistd.h>
 #include<inttypes.h>
 
